==> jexpress-2.3.12-sources.jar: org/summerboot/jexpress/integration/quartz/GuiceSchedulerProvider.java <==
/*
 * Copyright 2005-2022 Du Law Office - The Summer Boot Framework Project
 *
 * The Summer Boot Project licenses this file to you under the Apache License, version 2.0 (the
 * "License"); you may not use this file except in compliance with the License and you have no
 * policy prohibiting employee contributions back to this file (unless the contributor to this
 * file is your current or retired employee). You may obtain a copy of the License at:
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.summerboot.jexpress.integration.quartz;

import com.google.inject.Inject;
import com.google.inject.Injector;
import com.google.inject.Provider;
import org.quartz.Scheduler;
import org.quartz.SchedulerException;
import org.quartz.impl.StdSchedulerFactory;

/**
 * need to add the following into GuiceModule:
 * bind(Scheduler.class).toProvider(GuiceSchedulerProvider.class).asEagerSingleton();
 *
 * @author Changski Tie Zheng Zhang 张铁铮, 魏泽北, 杜旺财, 杜富贵
 */
public class GuiceSchedulerProvider implements Provider<Scheduler> {

    @Inject
    private Injector injector;

    @Override
    public Scheduler get() {
        try {
            StdSchedulerFactory factory = new StdSchedulerFactory();
            Scheduler scheduler = factory.getScheduler();

            scheduler.setJobFactory(new GuiceJobFactory(injector));
            scheduler.getListenerManager().addJobListener(new BootJobListener());
            return scheduler;
        } catch (SchedulerException ex) {
            throw new RuntimeException("Failed to provide a Scheduler", ex);
        }
    }

}

==> jexpress-2.4.12-sources.jar: org/summerboot/jexpress/integration/quartz/GuiceSchedulerProvider.java <==
/*
 * Copyright 2005-2022 Du Law Office - The Summer Boot Framework Project
 *
 * The Summer Boot Project licenses this file to you under the Apache License, version 2.0 (the
 * "License"); you may not use this file except in compliance with the License and you have no
 * policy prohibiting employee contributions back to this file (unless the contributor to this
 * file is your current or retired employee). You may obtain a copy of the License at:
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.summerboot.jexpress.integration.quartz;

import com.google.inject.Inject;
import com.google.inject.Injector;
import com.google.inject.Provider;
import org.quartz.Scheduler;
import org.quartz.SchedulerException;
import org.quartz.impl.StdSchedulerFactory;

/**
 * need to add the following into GuiceModule:
 * bind(Scheduler.class).toProvider(GuiceSchedulerProvider.class).asEagerSingleton();
 *
 * @author Changski Tie Zheng Zhang 张铁铮, 魏泽北, 杜旺财, 杜富贵
 */
public class GuiceSchedulerProvider implements Provider<Scheduler> {

    @Inject
    protected Injector injector;

    @Override
    public Scheduler get() {
        try {
            StdSchedulerFactory factory = new StdSchedulerFactory();
            Scheduler scheduler = factory.getScheduler();

            scheduler.setJobFactory(new GuiceJobFactory(injector));
            scheduler.getListenerManager().addJobListener(new BootJobListener());
            return scheduler;
        } catch (SchedulerException ex) {
            throw new RuntimeException("Failed to provide a Scheduler", ex);
        }
    }

}
